chicken_turtle_util.iterable
============================

.. automodule:: chicken_turtle_util.iterable

.. autosummary::
   :nosignatures:

   flatten
   is_sorted
   partition
   sliding_window

.. autofunction:: flatten
.. autofunction:: is_sorted
.. autofunction:: partition
.. autofunction:: sliding_window
